@@ -11,19 +11,27 @@ function LightDM() {
 
 function SDDM() {
       if [[ $(grep -n "Current=" /etc/sddm.conf | cut -f1 -d ":" | wc -l) -le 0 ]]; then
-            echo "[Theme]" >> /etc/sddm.conf
-            echo "Current=something" >> /etc/sddm.conf
+            if [[ $(grep -n "[Theme]" /etc/sddm.conf | wc -l) -le 0 ]]; then
+                  echo "[Theme]" >> /etc/sddm.conf
+            fi
+            echo "Current=$1" >> /etc/sddm.conf
+      else
+            line_number=$(grep -n "Current=" /etc/sddm.conf | cut -f1 -d ":")
+            sed -i "${line_number}s|.*|Current=$1|" /etc/sddm.conf
       fi
-      line_number=grep -n "Current=" /etc/sddm.conf | cut -f1 -d ":"
-      sed -i "${line_number}s|.*|$1|" /etc/sddm.conf
 }
 
 function TestLightdm() {
-      currentTheme=grep -n "greeter-session" /etc/lightdm/lightdm.conf | grep -v "Session to load for greeter" | sed "s|^.*=||"
-      line_number=grep -n "greeter-session" /etc/lightdm/lightdm.conf | grep -v "Session to load for greeter" | cut -f1 -d ":"
-      pkexec sed -i "${line_number}s|.*|$1|" etc/lightdm/lightdm.conf
+      if [ ! -f /usr/bin/Xephyr ] || [ ! -f /usr/bin/lightdm-gtk-greeter ] || [ ! -f /usr/bin/lightdm-webkit2-greeter ]; then
+
+            pkexec pacman -S xorg-server-xephyr lightdm-gtk-greeter lightdm-webkit2-greeter --needed --noconfirm
+      fi
+      originalText=$(grep "greeter-session" /etc/lightdm/lightdm.conf | grep -v "Session to load for greeter")
+      currentTheme=$(grep -n "greeter-session" /etc/lightdm/lightdm.conf | grep -v "Session to load for greeter" | sed "s|^.*=||")
+      line_number=$(grep -n "greeter-session" /etc/lightdm/lightdm.conf | grep -v "Session to load for greeter" | cut -f1 -d ":")
+      pkexec sed -i "${line_number}s|.*|greeter-session=$1|" /etc/lightdm/lightdm.conf
       lightdm --test-mode --debug
-      pkexec sed -i "${line_number}s|.*|$currentTheme|" etc/lightdm/lightdm.conf
+      pkexec sed -i "${line_number}s|.*|$originalText|" /etc/lightdm/lightdm.conf
 }
 
 function SDDMdefault() {
@@ -449,7 +457,13 @@ StartMycroft()
       RUSER_UID=$(id -u ${RUID})
       USER_HOME=$(grep ${RUID} /etc/passwd | rev | cut -f2 -d : | rev)
 
-      sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" $USER_HOME/mycroft-core/start-mycroft.sh all &
+      if [ ! -d $USER_HOME/mycroft-core ]; then
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft is not installed" "Cannot run commands" -a "RebornOS FIRE" -u critical -i "/usr/share/icons/default/reborn-updates.svg"
+      else
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" $USER_HOME/mycroft-core/start-mycroft.sh all &
+            # Display an update for the user via a notification
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft is ready for you" -a "RebornOS FIRE" -u normal -i "/usr/share/icons/default/reborn-updates.svg"
+      fi
 }
 
 StopMycroft()
@@ -462,7 +476,13 @@ StopMycroft()
       RUSER_UID=$(id -u ${RUID})
       USER_HOME=$(grep ${RUID} /etc/passwd | rev | cut -f2 -d : | rev)
 
-      sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" $USER_HOME/mycroft-core/stop-mycroft.sh
+      if [ ! -d $USER_HOME/mycroft-core ]; then
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft is not installed" "Cannot run commands" -a "RebornOS FIRE" -u critical -i "/usr/share/icons/default/reborn-updates.svg"
+      else
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" $USER_HOME/mycroft-core/stop-mycroft.sh
+            # Display an update for the user via a notification
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft has been terminated" -a "RebornOS FIRE" -u normal -i "/usr/share/icons/default/reborn-updates.svg"
+      fi
 }
 
 TextMycroft()
@@ -475,19 +495,26 @@ TextMycroft()
       RUSER_UID=$(id -u ${RUID})
       USER_HOME=$(grep ${RUID} /etc/passwd | rev | cut -f2 -d : | rev)
 
-      # Run command as the user running Mycroft, outputting everything to a text file so as to record the PID that is held therein
-      sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" echo "$1" | $USER_HOME/mycroft-core/bin/mycroft-cli-client > $USER_HOME/mycroft.txt &
+      if [ ! -d $USER_HOME/mycroft-core ]; then
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft is not installed" "Cannot run commands" -a "RebornOS FIRE" -u critical -i "/usr/share/icons/default/reborn-updates.svg"
+      else
+            # Run command as the user running Mycroft, outputting everything to a text file so as to record the PID that is held therein
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" echo "$1" | $USER_HOME/mycroft-core/bin/mycroft-cli-client > $USER_HOME/mycroft.txt &
 
-      while [[ $(grep "| INFO " $USER_HOME/mycroft.txt | grep "Connected" | wc -l) -eq 0 ]]; do
-            echo "Waiting for the connection to be made with Mycroft..."
-      done
+            while [[ $(grep "| INFO " $USER_HOME/mycroft.txt | grep "Connected" | wc -l) -eq 0 ]]; do
+                  echo "Waiting for the connection to be made with Mycroft..."
+            done
 
-      MYCROFT_PID=$(grep "| INFO " $USER_HOME/mycroft.txt | grep "Connected" | awk '{print $8}')
-      # Wait 7 seconds before killing the process
-      sleep 7
+            MYCROFT_PID=$(grep "| INFO " $USER_HOME/mycroft.txt | grep "Connected" | awk '{print $8}')
+            # Wait 7 seconds before killing the process
+            sleep 7
 
-      # Kill the process
-      kill -SIGTERM $MYCROFT_PID
+            # Kill the process
+            kill -SIGTERM $MYCROFT_PID
+
+            # Display an update for the user via a notification
+            sudo -u ${RUID} DBUS_SESSION_BUS_ADDRESS="unix:path=/run/user/${RUSER_UID}/bus" notify-send  "Mycroft is now built and ready to go!" -a "RebornOS FIRE" -u normal -i "/usr/share/icons/default/reborn-updates.svg"
+      fi
 }
 
 RemoveMycroft()
